@@ -250,6 +250,37 @@ class Plinux:
     def get_hostname(self):
         return self.run_cmd('hostname')
 
+    def get_package_version(self, package: str) -> ResponseParser:
+        """Get package (.deb) version
+
+        :param package: Deb name
+        :return:
+        """
+
+        cmd = f"dpkg -s {package} | grep Version | awk '{{print $2}}'"
+        return self.run_cmd(cmd)
+
+    def is_package_upgradable(self, package: str, show_version: bool = True) -> Union[bool, str]:
+        """Check package newer version. Return it if exists.
+
+        :param show_version:
+        :param package:
+        :return:
+        """
+
+        cmd = f"apt list --installed {package} 2>/dev/null | egrep -o '\[.*\]'"
+        result = self.run_cmd(cmd).stdout
+
+        try:
+            if 'upgradable' in result:  # There is newer package version
+                if show_version:  # Get precise version
+                    new_version = result.split('to: ')[1].removesuffix(']')
+                    return new_version
+                return True
+        except TypeError:
+            self.logger.error(f'Package ({package}) not found on destination server.')
+        return False
+
     # FIXME
     def change_hostname(self, name: str):
         cmd = f'{self.__sudo_cmd} -- sh -c "echo {name} > /etc/hostname; hostname -F /etc/hostname"'
@@ -380,6 +411,16 @@ class Plinux:
     def create_file(self, path: str, sudo: bool = True):
         return self.run_cmd(f'touch {path}', sudo=sudo)
 
+    def clear_file(self, path: str, sudo: bool = True):
+        """Clear file.
+
+        :param path:
+        :param sudo:
+        :return:
+        """
+
+        return self.run_cmd(f'cat /dev/null > {path}', sudo=sudo)
+
     def get_file_permissions(self, path: str, human: bool = False, sudo: bool = False):
         """Display file or file system status.
 
@@ -528,6 +569,11 @@ class Plinux:
         return self.run_cmd(cmd, sudo=sudo)
 
     def count_files(self, path: str):
+        """Count files number in directory.
+
+        :param path:
+        :return:
+        """
         return self.run_cmd(f'ls {path} | wc -l')
 
     #  ----------- SFTP -----------
@@ -619,6 +665,38 @@ class Plinux:
         cmd = f'sqlite3 {db} "{sql}" {params}'
         return self.run_cmd(cmd, sudo=sudo)
 
+    # OpenSSL
+    def validate_ssl_key(self, path: str) -> bool:
+        """Validate key
+
+        :param path: key path
+        :return:
+        """
+
+        result = self.run_cmd(f'openssl rsa -in {path} -check')
+        return True if 'RSA key ok' in result.stdout else False
+
+    def get_ssl_md5(self, path: str):
+        """Get cert or key md5
+
+        :param path:
+        :return:
+        """
+
+        return self.run_cmd(f'openssl x509 -noout -modulus -in {path} | openssl md5')
+
+    def get_ssl_certificate(self, x509: bool = True):
+        """Get certificate info
+
+        :param x509: Get x509 if specified
+        :return:
+        """
+
+        cmd = 'openssl s_client -showcerts -connect 172.16.0.124:443 </dev/null'
+        if x509:
+            cmd += ' | openssl x509 -text'
+        return self.run_cmd(cmd)
+
     # Aliases
     ps = get_processes
     ls = list_dir
